resultSetStore

|  | ## Cheshire3: resultSetStore Module

Module resultSetStore

Classes | [hide private]
SimpleResultSetStore |
BdbResultSetStore |
BdbResultSetStore2 |

Variables | [hide private]
use4Suite |
randomGen |
asciiChars |

Variables Details | [hide private]

    ### use4Suite Value:
        1

    ### randomGen Value:
        <random.Random object at 0x8879a64>

    ### asciiChars Value:
        'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789@%#!-=.\
        '